==> homesitemaker-v0.4.5.tar.gz: homesitemaker/includes/control-panel/users/cp_delete_user.php <==
<?php

/*
Home Site Maker, the websites factory.
Copyright (C) 2004, 2005 Marcos Martinez Jimenez

This file is part of Home Site Maker.

    Home Site Maker is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    Home Site Maker is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with Home Site Maker; see the file COPYING. If not, write to the Free Software
    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA


Marcos Martinez Jimenez
marcos@assl-site.net
http://homesitemaker.no-ip.org
Francesc Llunell n 1 4 5, Esplugues de Llobregat, 08950 Barcelona, Spain
*/


include ("includes/languages/".$LANGUAGE."/homesite-includes-control-panel-users-cp_delete_user.php");
echo "<tr><td class=\"title1\" colspan=\"2\">$TEXT001<br>&nbsp;</td></tr>";

// Get users list 
$users_list_query=mysql_query("SELECT id_user, nick,real_name,level FROM users", $db);
// Get the number of registered users
$n=mysql_num_rows ($users_list_query);
// If the user was loged in and select the add users option (task=add), then he can modify the whole section.
if ($id_session[num] == $num && $id_session[num] != "")
  {
  echo "<form enctype=\"multipart/form-data\" method=\"post\" ".
       "action=\"index.php?top_tab=$top_tab&section_type=$section_type&num=$num&user_section=4\">".
       "<input type=\"hidden\" name=\"dbwa\" value=\"dbwa_delete_user\">".
       "<input type=\"hidden\" name=\"num\" value=\"$num\">".
       "<tr><td class=\"text2\" colspan=\"4\" align=\"center\">$TEXT002 $n $TEXT003".
       "<br>&nbsp;</td></tr>".
       "<tr><td class=\"text2\"><b>$TEXT004</b></td>".
       "<td class=\"text2\"><b>$TEXT005</b></td>".
       "<td class=\"text2\"><b>$TEXT006</b></td>".
       "<td class=\"text2\"><b>$TEXT007</b></td></tr>";

  while ($users_list_result=mysql_fetch_array ($users_list_query))
    {
    echo "<tr><td><INPUT type=\"radio\" name=\"id_user\" value=\"".$users_list_result["id_user"]."\"></td>".
         "<td class=\"text2\">".$users_list_result["nick"]."</td>".
         "<td class=\"text2\">".$users_list_result["real_name"]."</td>".
         "<td class=\"text2\">".$users_list_result["level"]."</td></tr>";
    }
  }
echo "<tr><td class=\"text1\"colspan=5 align=\"center\"><br><br>".
     "<input type=\"submit\" value=\"$TEXT008\"></input><br></td></tr>".
     "</form>";
?>

==> homesitemaker-v0.4.7-1.tar.gz: homesitemaker/includes/control-panel/users/cp_delete_user.php <==
<?php

/*
Home Site Maker, the websites factory.
Copyright (C) 2004, 2005 Marcos Martinez Jimenez

This file is part of Home Site Maker.

    Home Site Maker is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    Home Site Maker is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with Home Site Maker; see the file COPYING. If not, write to the Free Software
    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA


Marcos Martinez Jimenez
marcos@assl-site.net
http://homesitemaker.no-ip.org
Francesc Llunell n 1 4 5, Esplugues de Llobregat, 08950 Barcelona, Spain
*/


include ("includes/languages/".$LANGUAGE."/homesite-includes-control-panel-users-cp_delete_user.php");
echo "<tr><td class=\"title1\" colspan=\"4\"><img src=\"images/skins/$ICONS/icons/png/$ICON_SIZE2/Delete_Users.png\">$TEXT001<br>&nbsp;</td></tr>";

// Get users list 
$users_list_query=mysql_query("SELECT id_user, nick,real_name,level FROM users", $db);
// Get the number of registered users
$n=mysql_num_rows ($users_list_query);
// If the user was loged in and select the add users option (task=add), then he can modify the whole section.
if ($id_session[num] == $num && $id_session[num] != "")
  {
  echo "<form enctype=\"multipart/form-data\" method=\"post\" ".
       "action=\"index.php?top_tab=$top_tab&section_type=$section_type&num=$num&user_section=4\">".
       "<input type=\"hidden\" name=\"dbwa\" value=\"dbwa_delete_user\">".
       "<input type=\"hidden\" name=\"num\" value=\"$num\">".
       "<tr><td class=\"text2\" colspan=\"4\" align=\"center\">$TEXT002 $n $TEXT003".
       "<br>&nbsp;</td></tr>".
       "<tr><td class=\"text2\"><b>$TEXT004</b></td>".
       "<td class=\"text2\"><b>$TEXT005</b></td>".
       "<td class=\"text2\"><b>$TEXT006</b></td>".
       "<td class=\"text2\"><b>$TEXT007</b></td></tr>";

  while ($users_list_result=mysql_fetch_array ($users_list_query))
    {
    echo "<tr><td><INPUT type=\"radio\" name=\"id_user\" value=\"".$users_list_result["id_user"]."\"></td>".
         "<td class=\"text2\">".$users_list_result["nick"]."</td>".
         "<td class=\"text2\">".$users_list_result["real_name"]."</td>".
         "<td class=\"text2\">".$users_list_result["level"]."</td></tr>";
    }
  }
echo "<tr><td class=\"text1\"colspan=5 align=\"center\"><br><br>".
     "<input type=\"submit\" value=\"$TEXT008\"></input><br></td></tr>".
     "</form>";
?>
